@@ -2,7 +2,7 @@
 asyncapi
 """
 
-__version__ = '0.5.0'
+__version__ = '0.6.0'
 from .api import AsyncApi, OperationsTypeHint
 from .builder import (
     build_api,
@@ -33,6 +33,9 @@ from .exceptions import (
 from .subscriber import run as run_subscriber
 
 
+from .docs import run as run_docs  # isort: skip
+
+
 __all__ = [
     'Channel',
     'Components',
@@ -57,4 +60,5 @@ __all__ = [
     'ReferenceNotFoundError',
     'UrlOrModuleRequiredError',
     'run_subscriber',
+    'run_docs',
 ]
